@@ -1,5 +1,5 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2018 openpyxl
+# Copyright (c) 2010-2019 openpyxl
 
 from collections import OrderedDict
 
@@ -51,7 +51,7 @@ class ChartBase(Serialisable):
     layout = Typed(expected_type=Layout, allow_none=True)
     roundedCorners = Bool(allow_none=True)
     axId = ValueSequence(expected_type=int)
-    visible_cells_only = Bool()
+    visible_cells_only = Bool(allow_none=True)
     display_blanks = Set(values=['span', 'gap', 'zero'])
 
     _series_type = ""
@@ -81,6 +81,10 @@ class ChartBase(Serialisable):
         self.plot_area = PlotArea()
         self.axId = axId
         self.display_blanks = 'gap'
+        self.pivotSource = None
+        self.pivotFormats = ()
+        self.visible_cells_only = True
+        self.idx_base = 0
 
 
     def __hash__(self):
@@ -111,7 +115,7 @@ class ChartBase(Serialisable):
         from .chartspace import ChartSpace, ChartContainer
         self.plot_area.layout = self.layout
 
-        idx_base = 0
+        idx_base = self.idx_base
         for chart in self._charts:
             if chart not in self.plot_area._charts:
                 chart.idx_base = idx_base
@@ -126,9 +130,11 @@ class ChartBase(Serialisable):
             container.backWall = chart.backWall
         container.plotVisOnly = self.visible_cells_only
         container.dispBlanksAs = self.display_blanks
+        container.pivotFmts = self.pivotFormats
         cs = ChartSpace(chart=container)
         cs.style = self.style
         cs.roundedCorners = self.roundedCorners
+        cs.pivotSource = self.pivotSource
         return cs.to_tree()
 
 
@@ -164,10 +170,9 @@ class ChartBase(Serialisable):
         else:
             values = data.cols
 
-        for v in values:
-            range_string = u"{0}!{1}:{2}".format(data.sheetname, v[0], v[-1])
-            series = SeriesFactory(range_string, title_from_data=titles_from_data)
-            self.ser.append(series)
+        for ref in values:
+            series = SeriesFactory(ref, title_from_data=titles_from_data)
+            self.series.append(series)
 
 
     def append(self, value):
