@@ -4,7 +4,7 @@ from __future__ import absolute_import
 """
 File manifest
 """
-import mimetypes
+from mimetypes import MimeTypes
 import os.path
 
 from openpyxl.descriptors.serialisable import Serialisable
@@ -32,13 +32,15 @@ from openpyxl.xml.constants import (
     CHART_TYPE,
     CHARTSHAPE_TYPE,
     CHARTSHEET_TYPE,
-    CONTYPES_NS
+    CONTYPES_NS,
+    ACTIVEX,
+    CTRL,
+    VBA,
 )
 from openpyxl.xml.functions import tostring
 
 # initialise mime-types
-if not mimetypes.inited:
-    mimetypes.init()
+mimetypes = MimeTypes()
 mimetypes.add_type('application/xml', ".xml")
 mimetypes.add_type('application/vnd.openxmlformats-package.relationships+xml', ".rels")
 mimetypes.add_type("application/vnd.ms-office.vbaProject", ".bin")
@@ -117,7 +119,7 @@ class Manifest(Serialisable):
         Skip parts without extensions
         """
         exts = set([os.path.splitext(part.PartName)[-1] for part in self.Override])
-        return [(ext[1:], mimetypes.types_map[ext]) for ext in sorted(exts) if ext]
+        return [(ext[1:], mimetypes.types_map[True][ext]) for ext in sorted(exts) if ext]
 
 
     def to_tree(self):
@@ -189,7 +191,7 @@ class Manifest(Serialisable):
             ext = os.path.splitext(fn)[-1]
             if not ext:
                 continue
-            mime = mimetypes.types_map[ext]
+            mime = mimetypes.types_map[True][ext]
             fe = FileExtension(ext[1:], mime)
             self.Default.append(fe)
 
@@ -203,5 +205,7 @@ class Manifest(Serialisable):
             mf = Manifest.from_tree(node)
             filenames = self.filenames
             for override in mf.Override:
+                if override.PartName not in (ACTIVEX, CTRL, VBA):
+                    continue
                 if override.PartName not in filenames:
                     self.Override.append(override)
