@@ -135,7 +135,11 @@ def is_builtin(fmt):
 
 def builtin_format_code(index):
     """Return one of the standard format codes by index."""
-    return BUILTIN_FORMATS[index]
+    try:
+        fmt = BUILTIN_FORMATS[index]
+    except KeyError:
+        fmt = None
+    return fmt
 
 
 def builtin_format_id(fmt):
